Structs
- Error implemenation for
crate::SimpleGarnishData. - Default custom type for
SimpleGarnishDatawhen no custom types are needed. - Custom size iterator for
garnish_lang_traits::GarnishDataimplementation. - List of
SimpleDatawith maps to convert symbolic values to original string. - Implementation of
GarnishData. Uses standard Rust collections for storing data. - Container for
Instructionand any data need by those instructions during execution. - Custom size iterator for
garnish_lang_traits::GarnishDataimplementation.
Enums
- Data object to give
GarnishDataTypetyped values. Can be passed a type parameter to extend supported data. - Number data type for
garnish_lang_traits::GarnishData. Implements all math operations and switches betweeni32andf64depending on operands.
Traits
Functions
- Called when building instructions to parse strings into byte lists.
- Called when building instructions to parse strings into character lists.
- Called when building instructions to parse strings into
SimpleNumber. - Utility to convert strings to
u64, the Symbol type forSimpleGarnishData.
Type Aliases
- Alias for simple error type
- Alias for
SimpleDatawithNoCustomtype parameter. - Alias for
SimpleGarnishDatawithNoCustomtype parameter.